@@ -1,9 +1,8 @@
 import datetime
 import json
 from argparse import ArgumentParser, Namespace, _SubParsersAction
-from curses.ascii import isdigit
 from pprint import pformat
-from typing import Any, List, Optional, Union, no_type_check
+from typing import Any, List, Optional, Union, cast, no_type_check
 
 from pycliarr.api import base_api, base_media, exceptions, radarr, sonarr
 from pycliarr.cli.utils import size_to_str
@@ -21,7 +20,7 @@ class CliCommand:
     def configure_args(self, cmdlist_parser: _SubParsersAction) -> ArgumentParser:
         cmd_parser = cmdlist_parser.add_parser(self.name, help=self.description)
         cmd_parser.set_defaults(cmd_name=self.name)
-        return cmd_parser
+        return cast(ArgumentParser, cmd_parser)
 
     def run(self, cli: Any, args: Namespace) -> None:
         pass
@@ -102,7 +101,7 @@ def select_item(
         raise Exception("Invalid selection: {}")
 
 
-def print_root_folder(cli: base_media.BaseCliMediaApi) -> int:
+def print_root_folder(cli: base_media.BaseCliMediaApi) -> None:
     res = cli.get_root_folder()
     print("Id  Free       Path")
     for root_folder in res:
@@ -111,14 +110,14 @@ def print_root_folder(cli: base_media.BaseCliMediaApi) -> int:
 
 def select_root_folder(cli: base_media.BaseCliMediaApi) -> int:
     print_root_folder(cli)
-    root_folder_id = input(f"Root folder to use (Id):")
+    root_folder_id = input("Root folder to use (Id):")
     if root_folder_id.isdigit():
         return int(root_folder_id)
     else:
         raise Exception("Invalid root folder selection, must be the folder id: {root_folder_id}")
 
 
-def root_folder_id_from_arg(cli: base_media.BaseCliMediaApi, root_arg: str):
+def root_folder_id_from_arg(cli: base_media.BaseCliMediaApi, root_arg: str) -> int:
     if root_arg:
         if root_arg == "auto":
             # Interactive selection
@@ -592,7 +591,8 @@ class CliAddMovieCommand(CliCommand):
         cmd_parser.add_argument("--quality", "-q", help="Quality profile to use", type=int, default=None)
         cmd_parser.add_argument("--path", help="Full path where the serie should be stored", type=str, default=None)
         cmd_parser.add_argument(
-            "--root-folder", '-r',
+            "--root-folder",
+            "-r",
             help="Root folder id or path, or 'auto' to select it interactively. Ignored if --path is set",
             type=str,
             default=None,
@@ -776,7 +776,8 @@ class CliAddSerieCommand(CliCommand):
         )
         cmd_parser.add_argument("--path", help="Full path where the serie should be stored", type=str, default=None)
         cmd_parser.add_argument(
-            "--root-folder", '-r',
+            "--root-folder",
+            "-r",
             help="Root folder id or path, or 'auto' to select it interactively. Ignored if --path is set",
             type=str,
             default=None,
